BoundOrdering

Enum BoundOrdering 

pub enum BoundOrdering {
    Within,
    Outside,
    Incomparable,
}
Position of a value relative to a single bound of a range.

This is the building block of RangePosition. For a lower bound, Within means the value satisfies the bound (it is greater than, or equal to, the bound depending on inclusiveness) and Outside means it is below it. For an upper bound, the meaning is mirrored.

Variants



Within

The value is on the inner side of the bound (it satisfies the bound).



Outside

The value is on the outer side of the bound (it violates the bound).



Incomparable

The value is incomparable with the bound. This can only happen for types that are PartialOrd but not Ord.